@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.19.4.39 1996/07/08 18:34:12 wessels Exp $
+ * $Id: squid.h,v 1.19.4.40 1996/07/08 22:25:15 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -257,7 +257,7 @@ extern char localhost[];
 
 
 /* Prototypes and definitions which don't really deserve a seaprate
-   include file */
+ * include file */
 
 #define  CONNECT_PORT        443
 
